@@ -1,12 +1,9 @@
-package MooseX::Getopt;
-BEGIN {
-  $MooseX::Getopt::AUTHORITY = 'cpan:STEVAN';
-}
-# git description: v0.63-8-g1e63eb5
-$MooseX::Getopt::VERSION = '0.64';
+package MooseX::Getopt; # git description: v0.67-7-g7122518
 # ABSTRACT: A Moose role for processing command line options
 # KEYWORDS: moose extension command line options attributes executable flags switches arguments
 
+our $VERSION = '0.68';
+
 use Moose::Role 0.56;
 use namespace::autoclean;
 
@@ -26,7 +23,7 @@ MooseX::Getopt - A Moose role for processing command line options
 
 =head1 VERSION
 
-version 0.64
+version 0.68
 
 =head1 SYNOPSIS
 
@@ -310,87 +307,17 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 CONTRIBUTORS
 
+=for stopwords Karen Etheridge Tomas Doran Stevan Little Yuval Kogman Florian Ragwitz Brandon L Black Shlomi Fish Hans Dieter Pearcey Ryan D Johnson Nelo Onyiah Ricardo SIGNES Ævar Arnfjörð Bjarmason Damien Krotkine Hinrik Örn Sigurðsson Todd Hepler Devin Austin Jose Luis Martinez Chris Prather Justin Hunter Gordon Irving Dagfinn Ilmari Mannsåker Jesse Luehrs Olaf Alders Jonathan Swartz John Goulah
+
 =over 4
 
 =item *
 
-Brandon L Black <blblack@gmail.com>
-
-=item *
-
-Chris Prather <chris@prather.org>
-
-=item *
-
-Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
-
-=item *
-
-Damien Krotkine <dkrotkine@weborama.com>
-
-=item *
-
-Devin Austin <devin@devin-laptop.(none)>
-
-=item *
-
-Drew Taylor <drew@drewtaylor.com>
-
-=item *
-
-Florian Ragwitz <rafl@debian.org>
-
-=item *
-
-Gordon Irving <goraxe@goraxe.me.uk>
-
-=item *
-
-Hans Dieter Pearcey <hdp@weftsoar.net>
-
-=item *
-
-Hinrik Örn Sigurðsson <hinrik.sig@gmail.com>
-
-=item *
-
-Jesse Luehrs <doy@tozt.net>
-
-=item *
-
-John Goulah <jgoulah@cpan.org>
-
-=item *
-
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-Justin Hunter <justin.d.hunter@gmail.com>
-
-=item *
-
 Karen Etheridge <ether@cpan.org>
 
 =item *
 
-Nelo Onyiah <nelo.onyiah@gmail.com>
-
-=item *
-
-Olaf Alders <olaf@wundersolutions.com>
-
-=item *
-
-Ricardo SIGNES <rjbs@cpan.org>
-
-=item *
-
-Ryan D Johnson <ryan@innerfence.com>
-
-=item *
-
-Shlomi Fish <shlomif@iglu.org.il>
+Tomas Doran <bobtfish@bobtfish.net>
 
 =item *
 
@@ -398,20 +325,92 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
-Todd Hepler <thepler@employees.org>
-
-=item *
-
-Tomas Doran <bobtfish@bobtfish.net>
-
-=item *
-
 Yuval Kogman <nothingmuch@woobling.org>
 
 =item *
 
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Brandon L Black <blblack@gmail.com>
+
+=item *
+
+Shlomi Fish <shlomif@iglu.org.il>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=item *
+
+Ryan D Johnson <ryan@innerfence.com>
+
+=item *
+
+Nelo Onyiah <nelo.onyiah@gmail.com>
+
+=item *
+
+Ricardo SIGNES <rjbs@cpan.org>
+
+=item *
+
 Ævar Arnfjörð Bjarmason <avarab@gmail.com>
 
+=item *
+
+Damien Krotkine <dkrotkine@weborama.com>
+
+=item *
+
+Hinrik Örn Sigurðsson <hinrik.sig@gmail.com>
+
+=item *
+
+Todd Hepler <thepler@employees.org>
+
+=item *
+
+Devin Austin <dhoss@cpan.org>
+
+=item *
+
+Jose Luis Martinez <jlmartinez@capside.com>
+
+=item *
+
+Chris Prather <chris@prather.org>
+
+=item *
+
+Justin Hunter <justin.d.hunter@gmail.com>
+
+=item *
+
+Gordon Irving <goraxe@goraxe.me.uk>
+
+=item *
+
+Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Olaf Alders <olaf@wundersolutions.com>
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+John Goulah <jgoulah@cpan.org>
+
 =back
 
 =cut
