@@ -1,9 +1,8 @@
 package MooseX::Getopt::Basic;
-BEGIN {
-  $MooseX::Getopt::Basic::AUTHORITY = 'cpan:STEVAN';
-}
 # ABSTRACT: MooseX::Getopt::Basic - role to implement the Getopt::Long functionality
-$MooseX::Getopt::Basic::VERSION = '0.64';
+
+our $VERSION = '0.68';
+
 use Moose::Role;
 
 use MooseX::Getopt::OptionTypeMap;
@@ -102,11 +101,16 @@ sub new_with_options {
 
     my $pa = $class->process_argv(@params);
 
+    # $pa->constructor_params contains everything passed to new_with_options,
+    # so it may contain the "argv" key, which may not exist on the class
+    my %constructor_params = %{ $pa->constructor_params };
+    delete $constructor_params{argv} if (not $class->meta->find_attribute_by_name('argv'));
+
     $class->new(
         ARGV       => $pa->argv_copy,
         extra_argv => $pa->extra_argv,
         ( $pa->usage ? ( usage => $pa->usage ) : () ),
-        %{ $pa->constructor_params }, # explicit params to ->new
+        %constructor_params,  # explicit params to ->new
         %{ $pa->cli_params }, # params from CLI
     );
 }
@@ -283,7 +287,7 @@ MooseX::Getopt::Basic - MooseX::Getopt::Basic - role to implement the Getopt::Lo
 
 =head1 VERSION
 
-version 0.64
+version 0.68
 
 =head1 SYNOPSIS
 
